@@ -34,7 +34,7 @@
  *
  * WARNING: Never change nwipe_options after calling a method.
  *
- * NOTE: The nwipe_runmethod function appends a final pass to all methods.
+ * NOTE: The nwipe_runmethod function appends a user selectable final blanking (zero) pass to all methods.
  *
  */
 
@@ -131,9 +131,9 @@ void* nwipe_zero( void* ptr )
 
     /* setup for a zero-fill. */
 
-    char zerofill[1] = {'\x00'};
-    nwipe_pattern_t patterns[] = {{1, &zerofill[0]},  // pass 1: 0s
-                                  {0, NULL}};
+    char zerofill[1] = { '\x00' };
+    nwipe_pattern_t patterns[] = { { 1, &zerofill[0] },  // pass 1: 0s
+                                   { 0, NULL } };
 
     /* Run the method. */
     c->result = nwipe_runmethod( c, patterns );
@@ -163,7 +163,7 @@ void* nwipe_verify( void* ptr )
     c->wipe_status = 1;
 
     /* Do nothing because nwipe_runmethod appends a zero-fill. */
-    nwipe_pattern_t patterns[] = {{0, NULL}};
+    nwipe_pattern_t patterns[] = { { 0, NULL } };
 
     /* Run the method. */
     c->result = nwipe_runmethod( c, patterns );
@@ -199,14 +199,14 @@ void* nwipe_dod522022m( void* ptr )
     /* Random characters. (Elements 2 and 6 are unused.) */
     char dod[7];
 
-    nwipe_pattern_t patterns[] = {{1, &dod[0]},  // Pass 1: A random character.
-                                  {1, &dod[1]},  // Pass 2: The bitwise complement of pass 1.
-                                  {-1, ""},  // Pass 3: A random stream.
-                                  {1, &dod[3]},  // Pass 4: A random character.
-                                  {1, &dod[4]},  // Pass 5: A random character.
-                                  {1, &dod[5]},  // Pass 6: The bitwise complement of pass 5.
-                                  {-1, ""},  // Pass 7: A random stream.
-                                  {0, NULL}};
+    nwipe_pattern_t patterns[] = { { 1, &dod[0] },  // Pass 1: A random character.
+                                   { 1, &dod[1] },  // Pass 2: The bitwise complement of pass 1.
+                                   { -1, "" },  // Pass 3: A random stream.
+                                   { 1, &dod[3] },  // Pass 4: A random character.
+                                   { 1, &dod[4] },  // Pass 5: A random character.
+                                   { 1, &dod[5] },  // Pass 6: The bitwise complement of pass 5.
+                                   { -1, "" },  // Pass 7: A random stream.
+                                   { 0, NULL } };
 
     /* Load the array with random characters. */
     r = read( c->entropy_fd, &dod, sizeof( dod ) );
@@ -274,10 +274,10 @@ void* nwipe_dodshort( void* ptr )
     /* Random characters. (Element 3 is unused.) */
     char dod[3];
 
-    nwipe_pattern_t patterns[] = {{1, &dod[0]},  // Pass 1: A random character.
-                                  {1, &dod[1]},  // Pass 2: The bitwise complement of pass 1.
-                                  {-1, ""},  // Pass 3: A random stream.
-                                  {0, NULL}};
+    nwipe_pattern_t patterns[] = { { 1, &dod[0] },  // Pass 1: A random character.
+                                   { 1, &dod[1] },  // Pass 2: The bitwise complement of pass 1.
+                                   { -1, "" },  // Pass 3: A random stream.
+                                   { 0, NULL } };
 
     /* Load the array with random characters. */
     r = read( c->entropy_fd, &dod, sizeof( dod ) );
@@ -348,42 +348,42 @@ void* nwipe_gutmann( void* ptr )
     int n;
 
     /* Define the Gutmann method. */
-    nwipe_pattern_t book[] = {{-1, ""},  // Random pass.
-                              {-1, ""},  // Random pass.
-                              {-1, ""},  // Random pass.
-                              {-1, ""},  // Random pass.
-                              {3, "\x55\x55\x55"},  // Static pass: 0x555555  01010101 01010101 01010101
-                              {3, "\xAA\xAA\xAA"},  // Static pass: 0XAAAAAA  10101010 10101010 10101010
-                              {3, "\x92\x49\x24"},  // Static pass: 0x924924  10010010 01001001 00100100
-                              {3, "\x49\x24\x92"},  // Static pass: 0x492492  01001001 00100100 10010010
-                              {3, "\x24\x92\x49"},  // Static pass: 0x249249  00100100 10010010 01001001
-                              {3, "\x00\x00\x00"},  // Static pass: 0x000000  00000000 00000000 00000000
-                              {3, "\x11\x11\x11"},  // Static pass: 0x111111  00010001 00010001 00010001
-                              {3, "\x22\x22\x22"},  // Static pass: 0x222222  00100010 00100010 00100010
-                              {3, "\x33\x33\x33"},  // Static pass: 0x333333  00110011 00110011 00110011
-                              {3, "\x44\x44\x44"},  // Static pass: 0x444444  01000100 01000100 01000100
-                              {3, "\x55\x55\x55"},  // Static pass: 0x555555  01010101 01010101 01010101
-                              {3, "\x66\x66\x66"},  // Static pass: 0x666666  01100110 01100110 01100110
-                              {3, "\x77\x77\x77"},  // Static pass: 0x777777  01110111 01110111 01110111
-                              {3, "\x88\x88\x88"},  // Static pass: 0x888888  10001000 10001000 10001000
-                              {3, "\x99\x99\x99"},  // Static pass: 0x999999  10011001 10011001 10011001
-                              {3, "\xAA\xAA\xAA"},  // Static pass: 0xAAAAAA  10101010 10101010 10101010
-                              {3, "\xBB\xBB\xBB"},  // Static pass: 0xBBBBBB  10111011 10111011 10111011
-                              {3, "\xCC\xCC\xCC"},  // Static pass: 0xCCCCCC  11001100 11001100 11001100
-                              {3, "\xDD\xDD\xDD"},  // Static pass: 0xDDDDDD  11011101 11011101 11011101
-                              {3, "\xEE\xEE\xEE"},  // Static pass: 0xEEEEEE  11101110 11101110 11101110
-                              {3, "\xFF\xFF\xFF"},  // Static pass: 0xFFFFFF  11111111 11111111 11111111
-                              {3, "\x92\x49\x24"},  // Static pass: 0x924924  10010010 01001001 00100100
-                              {3, "\x49\x24\x92"},  // Static pass: 0x492492  01001001 00100100 10010010
-                              {3, "\x24\x92\x49"},  // Static pass: 0x249249  00100100 10010010 01001001
-                              {3, "\x6D\xB6\xDB"},  // Static pass: 0x6DB6DB  01101101 10110110 11011011
-                              {3, "\xB6\xDB\x6D"},  // Static pass: 0xB6DB6D  10110110 11011011 01101101
-                              {3, "\xDB\x6D\xB6"},  // Static pass: 0XDB6DB6  11011011 01101101 10110110
-                              {-1, ""},  // Random pass.
-                              {-1, ""},  // Random pass.
-                              {-1, ""},  // Random pass.
-                              {-1, ""},  // Random pass.
-                              {0, NULL}};
+    nwipe_pattern_t book[] = { { -1, "" },  // Random pass.
+                               { -1, "" },  // Random pass.
+                               { -1, "" },  // Random pass.
+                               { -1, "" },  // Random pass.
+                               { 3, "\x55\x55\x55" },  // Static pass: 0x555555  01010101 01010101 01010101
+                               { 3, "\xAA\xAA\xAA" },  // Static pass: 0XAAAAAA  10101010 10101010 10101010
+                               { 3, "\x92\x49\x24" },  // Static pass: 0x924924  10010010 01001001 00100100
+                               { 3, "\x49\x24\x92" },  // Static pass: 0x492492  01001001 00100100 10010010
+                               { 3, "\x24\x92\x49" },  // Static pass: 0x249249  00100100 10010010 01001001
+                               { 3, "\x00\x00\x00" },  // Static pass: 0x000000  00000000 00000000 00000000
+                               { 3, "\x11\x11\x11" },  // Static pass: 0x111111  00010001 00010001 00010001
+                               { 3, "\x22\x22\x22" },  // Static pass: 0x222222  00100010 00100010 00100010
+                               { 3, "\x33\x33\x33" },  // Static pass: 0x333333  00110011 00110011 00110011
+                               { 3, "\x44\x44\x44" },  // Static pass: 0x444444  01000100 01000100 01000100
+                               { 3, "\x55\x55\x55" },  // Static pass: 0x555555  01010101 01010101 01010101
+                               { 3, "\x66\x66\x66" },  // Static pass: 0x666666  01100110 01100110 01100110
+                               { 3, "\x77\x77\x77" },  // Static pass: 0x777777  01110111 01110111 01110111
+                               { 3, "\x88\x88\x88" },  // Static pass: 0x888888  10001000 10001000 10001000
+                               { 3, "\x99\x99\x99" },  // Static pass: 0x999999  10011001 10011001 10011001
+                               { 3, "\xAA\xAA\xAA" },  // Static pass: 0xAAAAAA  10101010 10101010 10101010
+                               { 3, "\xBB\xBB\xBB" },  // Static pass: 0xBBBBBB  10111011 10111011 10111011
+                               { 3, "\xCC\xCC\xCC" },  // Static pass: 0xCCCCCC  11001100 11001100 11001100
+                               { 3, "\xDD\xDD\xDD" },  // Static pass: 0xDDDDDD  11011101 11011101 11011101
+                               { 3, "\xEE\xEE\xEE" },  // Static pass: 0xEEEEEE  11101110 11101110 11101110
+                               { 3, "\xFF\xFF\xFF" },  // Static pass: 0xFFFFFF  11111111 11111111 11111111
+                               { 3, "\x92\x49\x24" },  // Static pass: 0x924924  10010010 01001001 00100100
+                               { 3, "\x49\x24\x92" },  // Static pass: 0x492492  01001001 00100100 10010010
+                               { 3, "\x24\x92\x49" },  // Static pass: 0x249249  00100100 10010010 01001001
+                               { 3, "\x6D\xB6\xDB" },  // Static pass: 0x6DB6DB  01101101 10110110 11011011
+                               { 3, "\xB6\xDB\x6D" },  // Static pass: 0xB6DB6D  10110110 11011011 01101101
+                               { 3, "\xDB\x6D\xB6" },  // Static pass: 0XDB6DB6  11011011 01101101 10110110
+                               { -1, "" },  // Random pass.
+                               { -1, "" },  // Random pass.
+                               { -1, "" },  // Random pass.
+                               { -1, "" },  // Random pass.
+                               { 0, NULL } };
 
     /* Put the book array into this array in random order. */
     nwipe_pattern_t patterns[36];
@@ -439,8 +439,6 @@ void* nwipe_gutmann( void* ptr )
 
         /* Mark this element as having been used. */
         book[j].length = 0;
-
-        nwipe_log( NWIPE_LOG_DEBUG, "nwipe_gutmann: Set patterns[%i] = book[%i].", i, j );
     }
 
     /* Ensure that the array is terminated. */
@@ -636,11 +634,11 @@ void* nwipe_is5enh( void* ptr )
 
     c->wipe_status = 1;
 
-    char is5enh[3] = {'\x00', '\xFF', '\x00'};
-    nwipe_pattern_t patterns[] = {{1, &is5enh[0]},  // Pass 1: 0s
-                                  {1, &is5enh[1]},  // Pass 2: 1s
-                                  {-1, &is5enh[2]},  // Pass 3: random bytes with verification
-                                  {0, NULL}};
+    char is5enh[3] = { '\x00', '\xFF', '\x00' };
+    nwipe_pattern_t patterns[] = { { 1, &is5enh[0] },  // Pass 1: 0s
+                                   { 1, &is5enh[1] },  // Pass 2: 1s
+                                   { -1, &is5enh[2] },  // Pass 3: random bytes with verification
+                                   { 0, NULL } };
     c->result = nwipe_runmethod( c, patterns );
 
     c->wipe_status = 0;
@@ -668,7 +666,7 @@ void* nwipe_random( void* ptr )
     c->wipe_status = 1;
 
     /* Define the random method. */
-    nwipe_pattern_t patterns[] = {{-1, ""}, {0, NULL}};
+    nwipe_pattern_t patterns[] = { { -1, "" }, { 0, NULL } };
 
     /* Run the method. */
     c->result = nwipe_runmethod( c, patterns );
@@ -701,7 +699,7 @@ int nwipe_runmethod( nwipe_context_t* c, nwipe_pattern_t* patterns )
     i = 0;
 
     /* The zero-fill pattern for the final pass of most methods. */
-    nwipe_pattern_t pattern_zero = {1, "\x00"};
+    nwipe_pattern_t pattern_zero = { 1, "\x00" };
 
     /* Create the PRNG state buffer. */
     c->prng_seed.length = NWIPE_KNOB_PRNG_STATE_LENGTH;
@@ -727,18 +725,6 @@ int nwipe_runmethod( nwipe_context_t* c, nwipe_pattern_t* patterns )
     /* Set the number of bytes that will be written across all passes in one round. */
     c->pass_size = c->pass_count * c->device_size;
 
-    if( nwipe_options.verify == NWIPE_VERIFY_ALL )
-    {
-        /* We must read back all passes, so double the byte count. */
-        c->pass_size *= 2;
-    }
-
-    /* Tell the parent the number of rounds that will be run. */
-    c->round_count = nwipe_options.rounds;
-
-    /* Set the initial number of bytes that will be written across all rounds. */
-    c->round_size = c->pass_size;
-
     /* For the selected method, calculate the correct round_size value (for correct percentage calculation) */
     calculate_round_size( c );
 
@@ -830,6 +816,8 @@ int nwipe_runmethod( nwipe_context_t* c, nwipe_pattern_t* patterns )
                     r = nwipe_static_verify( c, &patterns[i] );
                     c->pass_type = NWIPE_PASS_NONE;
 
+                    nwipe_log( NWIPE_LOG_NOTICE, "%llu bytes read from %s", c->pass_done, c->device_name );
+
                     /* Check for a fatal error. */
                     if( r < 0 )
                     {
@@ -902,6 +890,8 @@ int nwipe_runmethod( nwipe_context_t* c, nwipe_pattern_t* patterns )
                     r = nwipe_random_verify( c );
                     c->pass_type = NWIPE_PASS_NONE;
 
+                    nwipe_log( NWIPE_LOG_NOTICE, "%llu bytes read from %s", c->pass_done, c->device_name );
+
                     /* Check for a fatal error. */
                     if( r < 0 )
                     {
@@ -976,6 +966,8 @@ int nwipe_runmethod( nwipe_context_t* c, nwipe_pattern_t* patterns )
         /* The final ops2 pass. */
         r = nwipe_random_pass( c );
 
+        nwipe_log( NWIPE_LOG_NOTICE, "%llu bytes written to %s", c->pass_done, c->device_name );
+
         /* Check for a fatal error. */
         if( r < 0 )
         {
@@ -984,22 +976,22 @@ int nwipe_runmethod( nwipe_context_t* c, nwipe_pattern_t* patterns )
 
         if( nwipe_options.verify == NWIPE_VERIFY_LAST || nwipe_options.verify == NWIPE_VERIFY_ALL )
         {
-            nwipe_log( NWIPE_LOG_NOTICE, "Verifying the final random pattern on %s is empty.", c->device_name );
+            nwipe_log( NWIPE_LOG_NOTICE, "Verifying final random pattern FRP on %s", c->device_name );
 
             /* Verify the final zero pass. */
             r = nwipe_random_verify( c );
 
+            nwipe_log( NWIPE_LOG_NOTICE, "%llu bytes read from %s", c->pass_done, c->device_name );
+
             /* Check for a fatal error. */
             if( r < 0 )
             {
                 return r;
             }
 
-            nwipe_log( NWIPE_LOG_NOTICE, "Verified the final random pattern on '%s' is empty.", c->device_name );
+            nwipe_log( NWIPE_LOG_NOTICE, "[SUCCESS] Verified FRP on '%s' matches", c->device_name );
         }
 
-        nwipe_log( NWIPE_LOG_NOTICE, "Wrote final random pattern to '%s'.", c->device_name );
-
     } /* final ops2 */
 
     else if( nwipe_options.method == &nwipe_verify )
@@ -1022,7 +1014,7 @@ int nwipe_runmethod( nwipe_context_t* c, nwipe_pattern_t* patterns )
         }
         else
         {
-            nwipe_log( NWIPE_LOG_ERROR, "[FAILURE] %s IS NOT empty.", c->device_name );
+            nwipe_log( NWIPE_LOG_ERROR, "[FAILURE] %s is not empty .", c->device_name );
         }
 
     } /* verify */
@@ -1037,6 +1029,9 @@ int nwipe_runmethod( nwipe_context_t* c, nwipe_pattern_t* patterns )
         /* The final zero pass. */
         r = nwipe_static_pass( c, &pattern_zero );
 
+        /* Log number of bytes written to disk */
+        nwipe_log( NWIPE_LOG_NOTICE, "%llu bytes written to %s", c->pass_done, c->device_name );
+
         /* Check for a fatal error. */
         if( r < 0 )
         {
@@ -1048,7 +1043,12 @@ int nwipe_runmethod( nwipe_context_t* c, nwipe_pattern_t* patterns )
             nwipe_log( NWIPE_LOG_NOTICE, "Verifying that %s is empty.", c->device_name );
 
             /* Verify the final zero pass. */
+            c->pass_type = NWIPE_PASS_VERIFY;
             r = nwipe_static_verify( c, &pattern_zero );
+            c->pass_type = NWIPE_PASS_NONE;
+
+            /* Log number of bytes read from disk */
+            nwipe_log( NWIPE_LOG_NOTICE, "%llu bytes read from %s", c->pass_done, c->device_name );
 
             /* Check for a fatal error. */
             if( r < 0 )
@@ -1066,7 +1066,14 @@ int nwipe_runmethod( nwipe_context_t* c, nwipe_pattern_t* patterns )
             }
         }
 
-        nwipe_log( NWIPE_LOG_NOTICE, "[SUCCESS] Blanked device %s", c->device_name );
+        if( c->verify_errors == 0 && c->pass_errors == 0 )
+        {
+            nwipe_log( NWIPE_LOG_NOTICE, "[SUCCESS] Blanked device %s", c->device_name );
+        }
+        else
+        {
+            nwipe_log( NWIPE_LOG_NOTICE, "[FAILURE] %s may not be blanked", c->device_name );
+        }
 
     } /* final blank */
 
@@ -1104,24 +1111,23 @@ int nwipe_runmethod( nwipe_context_t* c, nwipe_pattern_t* patterns )
 
 void calculate_round_size( nwipe_context_t* c )
 {
-    /* This is where the round size is adjusted. round_size is used in the running percentage completion
+    /* This is where the round size is calculated. round_size is used in the running percentage completion
      * calculation. round size is calculated based on pass_size, pass_count, number of rounds, blanking
-     * on/off and verification on/off
+     * on/off and verification All/Last/None
      *
-     * To hopefully make this adjustment more understandable, I have presented each calculation
-     * under each method. This should make it easier to add a new method here without breaking the
-     * calculations for other methods.
+     * To hopefully make this calculation more understandable, I have separated the calculations that apply to
+     * all methods and processed first then created a switch statement that contains method specific changes if any
      */
 
     /* Don't change the order of these values as the case statements use their index in the array */
-    void* array_methods[] = {&nwipe_zero,
-                             &nwipe_ops2,
-                             &nwipe_dodshort,
-                             &nwipe_dod522022m,
-                             &nwipe_gutmann,
-                             &nwipe_random,
-                             &nwipe_is5enh,
-                             NULL};
+    void* array_methods[] = { &nwipe_zero,
+                              &nwipe_ops2,
+                              &nwipe_dodshort,
+                              &nwipe_dod522022m,
+                              &nwipe_gutmann,
+                              &nwipe_random,
+                              &nwipe_is5enh,
+                              NULL };
     int i;
 
     /* This while loop allows us to effectively create a const so we can use a case statement rather than if statements.
@@ -1141,118 +1147,110 @@ void calculate_round_size( nwipe_context_t* c )
         i++;
     }
 
-    /* Multiple the round_size by the number of rounds (times) the user wants to wipe the drive with this method.
-     */
+    if( nwipe_options.verify == NWIPE_VERIFY_ALL )
+    {
+        /* We must read back all passes, so double the byte count. */
+        c->pass_size *= 2;
+    }
+
+    /* Tell the parent the number of rounds that will be run. */
+    c->round_count = nwipe_options.rounds;
+
+    /* Set the initial number of bytes that will be written across all rounds.
+       c->pass_size includes write AND verification passes if 'verify_all' is selected
+       but does not include the final blanking pass or the verify_last option */
+    c->round_size = c->pass_size;
+
+    /* Multiple the round_size by the number of rounds (times) the user wants to wipe the drive with this method. */
     c->round_size *= c->round_count;
 
-    /* For each method create the correct round_size value */
+    /* Now increase size based on whether blanking is enabled and verification */
+    if( nwipe_options.noblank == 0 )
+    {
+        /* Blanking enabled so increase round size */
+        c->round_size += c->device_size;
+
+        if( nwipe_options.verify == NWIPE_VERIFY_LAST || nwipe_options.verify == NWIPE_VERIFY_ALL )
+        {
+            c->round_size += c->device_size;
+        }
+    }
+    else
+    {
+        /* Blanking not enabled, check for 'Verify_last', increase round size if enabled. */
+        if( nwipe_options.verify == NWIPE_VERIFY_LAST )
+        {
+            c->round_size += c->device_size;
+        }
+    }
+
+    /* Additional method specific round_size adjustments go in this switch statement */
+
     switch( selected_method )
     {
         case 0:
-            /* NWIPE_ZERO
+            /* NWIPE_ZERO - No additional calculation required
              * ---------- */
-
-            if( nwipe_options.verify == NWIPE_VERIFY_ALL )
-            {
-                c->round_size += c->device_size;
-            }
-            if( nwipe_options.verify == NWIPE_VERIFY_LAST )
-            {
-                c->round_size += c->device_size;
-            }
-            if( nwipe_options.noblank == 0 )
-            {
-                c->round_size += c->device_size;
-            }
             break;
 
         case 1:
             /* NWIPE_OPS2
              * ---------- */
 
-            /* Required for the 9th and final random pass */
+            /* Required for mandatory 9th and final random pass */
             c->round_size += c->device_size;
 
-            if( nwipe_options.verify == NWIPE_VERIFY_LAST )
+            /* Required for selectable 9th and final random verification */
+            if( nwipe_options.verify == NWIPE_VERIFY_ALL || nwipe_options.verify == NWIPE_VERIFY_LAST )
             {
                 c->round_size += c->device_size;
             }
-            if( nwipe_options.verify == NWIPE_VERIFY_ALL )
+
+            /* As no final zero blanking pass is permitted by this standard reduce round size if it's seelected */
+            if( nwipe_options.noblank == 0 )
             {
-                c->round_size += c->device_size;
+                /* Reduce for blanking pass */
+                c->round_size -= c->device_size;
+
+                /* Reduce for blanking pass verification */
+                if( nwipe_options.verify == NWIPE_VERIFY_ALL || nwipe_options.verify == NWIPE_VERIFY_LAST )
+                {
+                    c->round_size -= c->device_size;
+                }
             }
+            else
+            {
+                if( nwipe_options.verify == NWIPE_VERIFY_LAST )
+                {
+                    /* If blanking off & verification on reduce round size */
+                    c->round_size -= c->device_size;
+                }
+            }
+
             break;
 
         case 2:
-            /* DoD Short
+            /* DoD Short - No additional calculation required
              * --------- */
 
-            if( nwipe_options.verify == NWIPE_VERIFY_LAST )
-            {
-                c->round_size += c->device_size;
-            }
-            if( nwipe_options.verify == NWIPE_VERIFY_ALL )
-            {
-                c->round_size += c->device_size;
-            }
-            if( nwipe_options.noblank == 0 )
-            {
-                c->round_size += c->device_size;
-            }
             break;
 
         case 3:
-            /* DOD 522022m
+            /* DOD 522022m - No additional calculation required
              * ----------- */
 
-            if( nwipe_options.verify == NWIPE_VERIFY_LAST )
-            {
-                c->round_size += c->device_size;
-            }
-            if( nwipe_options.verify == NWIPE_VERIFY_ALL )
-            {
-                c->round_size += c->device_size;
-            }
-            if( nwipe_options.noblank == 0 )
-            {
-                c->round_size += c->device_size;
-            }
             break;
 
         case 4:
-            /* GutMann
+            /* GutMann - No additional calculation required
              * ------- */
 
-            if( nwipe_options.verify == NWIPE_VERIFY_LAST )
-            {
-                c->round_size += c->device_size;
-            }
-            if( nwipe_options.verify == NWIPE_VERIFY_ALL )
-            {
-                c->round_size += c->device_size;
-            }
-            if( nwipe_options.noblank == 0 )
-            {
-                c->round_size += c->device_size;
-            }
             break;
 
         case 5:
-            /* PRNG (random)
+            /* PRNG (random) - No additional calculation required
              * ------------- */
 
-            if( nwipe_options.verify == NWIPE_VERIFY_LAST )
-            {
-                c->round_size += c->device_size;
-            }
-            if( nwipe_options.verify == NWIPE_VERIFY_ALL )
-            {
-                c->round_size += c->device_size;
-            }
-            if( nwipe_options.noblank == 0 )
-            {
-                c->round_size += c->device_size;
-            }
             break;
 
         case 6:
@@ -1260,25 +1258,20 @@ void calculate_round_size( nwipe_context_t* c )
              * ------------ */
 
             /* This method ALWAYS verifies the 3rd pass so increase by device size,
-             * and does not need to be increased by device size for VERIFY_ALL*/
+             * but NOT if VERIFY_ALL has been selected, but first .. */
 
-            if( nwipe_options.verify == NWIPE_VERIFY_LAST )
+            /* Reduce as Verify_Last already included previously if blanking was off */
+            if( nwipe_options.verify == NWIPE_VERIFY_LAST && nwipe_options.noblank == 1 )
             {
-                c->round_size += c->device_size;
+                c->round_size -= c->device_size;
             }
-            if( nwipe_options.verify == NWIPE_VERIFY_ALL )
+
+            /* Adjusts for verify on every third pass multiplied by number of rounds */
+            if( nwipe_options.verify != NWIPE_VERIFY_ALL )
             {
-                c->round_size += c->device_size;
-            }
-            else
-            {
-                /* Adjusts for verify on every third pass multiplied by number of rounds */
                 c->round_size += ( c->device_size * c->round_count );
             }
-            if( nwipe_options.noblank == 0 )
-            {
-                c->round_size += c->device_size;
-            }
+
             break;
     }
 }
