@@ -32,7 +32,6 @@
 #include <signal.h>
 #include <pthread.h>
 #include <sys/types.h>
-#include <bits/sigthread.h>
 
 #include "nwipe.h"
 #include "context.h"
@@ -53,6 +52,7 @@
 
 int terminate_signal;
 int user_abort;
+int global_wipe_status;
 
 int main( int argc, char** argv )
 {
@@ -88,6 +88,13 @@ int main( int argc, char** argv )
     /* nwipes return status value, set prior to exit at the end of nwipe, as no other exit points allowed */
     int return_status = 0;
 
+    /* Initialise, flag indicating whether a wipe has actually started or not 0=no, 1=yes */
+    global_wipe_status = 0;
+
+    /* Initialise flags that indicates whether a fatal or non fatal error occured on ANY drive */
+    int fatal_errors_flag = 0;
+    int non_fatal_errors_flag = 0;
+
     /* Two arrays are used, containing pointers to the the typedef for each disk */
     /* The first array (c1) points to all devices, the second points to only     */
     /* the disks selected for wiping.                                            */
@@ -216,12 +223,6 @@ int main( int argc, char** argv )
             /* The user must manually select devices. */
             c1[i]->select = NWIPE_SELECT_FALSE;
         }
-
-        /* Set the PRNG implementation. */
-        c1[i]->prng = nwipe_options.prng;
-        c1[i]->prng_seed.length = 0;
-        c1[i]->prng_seed.s = 0;
-        c1[i]->prng_state = 0;
     }
 
     /* Check for initialization errors. */
@@ -257,9 +258,15 @@ int main( int argc, char** argv )
         }
     }
 
-    /* Count the number of selected contexts. */
     for( i = 0; i < nwipe_enumerated; i++ )
     {
+        /* Set the PRNG implementation, which must always come after the function nwipe_gui_select ! */
+        c1[i]->prng = nwipe_options.prng;
+        c1[i]->prng_seed.length = 0;
+        c1[i]->prng_seed.s = 0;
+        c1[i]->prng_state = 0;
+
+        /* Count the number of selected contexts. */
         if( c1[i]->select == NWIPE_SELECT_TRUE )
         {
             nwipe_selected += 1;
@@ -282,6 +289,12 @@ int main( int argc, char** argv )
     /* TODO: free c1 and c2 memory. */
     if( user_abort == 0 )
     {
+        /* Log the wipe options that have been selected immediately prior to the start of the wipe */
+        nwipe_options_log();
+
+        /* The wipe has been initiated */
+        global_wipe_status = 1;
+
         for( i = 0; i < nwipe_selected; i++ )
         {
             /* A result buffer for the BLKGETSIZE64 ioctl. */
@@ -583,6 +596,7 @@ int main( int argc, char** argv )
             if( c2[i]->result > 0 )
             {
                 nwipe_log( NWIPE_LOG_FATAL, "Nwipe exited with non fatal errors on device = %s\n", c2[i]->device_name );
+                non_fatal_errors_flag = 1;
                 return_status = 1;
             }
         }
@@ -593,6 +607,7 @@ int main( int argc, char** argv )
             if( c2[i]->result < 0 )
             {
                 nwipe_log( NWIPE_LOG_ERROR, "Nwipe exited with fatal errors on device = %s\n", c2[i]->device_name );
+                fatal_errors_flag = 1;
                 return_status = -1;
             }
         }
@@ -601,9 +616,33 @@ int main( int argc, char** argv )
     /* Generate and send the drive status summary to the log */
     nwipe_log_summary( c2, nwipe_selected );
 
-    if( return_status == 0 )
+    /* Print a one line status message for the user */
+    if( return_status == 0 || return_status == 1 )
     {
-        nwipe_log( NWIPE_LOG_INFO, "Nwipe successfully exited." );
+        if( user_abort == 1 )
+        {
+            if( global_wipe_status == 1 )
+            {
+                nwipe_log( NWIPE_LOG_INFO,
+                           "Nwipe was aborted by the user. Check the summary table for the drive status." );
+            }
+            else
+            {
+                nwipe_log( NWIPE_LOG_INFO, "Nwipe was aborted by the user prior to the wipe starting." );
+            }
+        }
+        else
+        {
+            if( fatal_errors_flag == 1 || non_fatal_errors_flag == 1 )
+            {
+                nwipe_log( NWIPE_LOG_INFO,
+                           "Nwipe exited with errors, check the log & summary table for individual drive status." );
+            }
+            else
+            {
+                nwipe_log( NWIPE_LOG_INFO, "Nwipe successfully completed. See summary table for details." );
+            }
+        }
     }
 
     cleanup();
@@ -778,7 +817,7 @@ int cleanup()
 }
 void check_for_autopoweroff( void )
 {
-    char cmd[] = "shutdown -P +1 \"System going down in one minute\"";
+    char cmd[] = "shutdown -Ph +1 \"System going down in one minute\"";
     FILE* fp;
     int r;  // A result buffer.
 
