@@ -73,6 +73,9 @@ void* signal_hand( void* );
 /* System errors. */
 extern int errno;
 
+/* 0=wipe not yet started, 1=wipe has been started by the user */
+extern int global_wipe_status;
+
 /* Global array to hold log values to print when logging to STDOUT */
 /* char **log_lines;
 int log_current_element = 0;
