@@ -58,58 +58,58 @@ int nwipe_options_parse( int argc, char** argv )
     /* The list of acceptable long options. */
     static struct option nwipe_options_long[] = {
         /* Set when the user wants to wipe without a confirmation prompt. */
-        {"autonuke", no_argument, 0, 0},
+        { "autonuke", no_argument, 0, 0 },
 
         /* Set when the user wants to have the system powerdown on completion of wipe. */
-        {"autopoweroff", no_argument, 0, 0},
+        { "autopoweroff", no_argument, 0, 0 },
 
         /* A GNU standard option. Corresponds to the 'h' short option. */
-        {"help", no_argument, 0, 'h'},
+        { "help", no_argument, 0, 'h' },
 
         /* The wipe method. Corresponds to the 'm' short option. */
-        {"method", required_argument, 0, 'm'},
+        { "method", required_argument, 0, 'm' },
 
         /* Log file. Corresponds to the 'l' short option. */
-        {"logfile", required_argument, 0, 'l'},
+        { "logfile", required_argument, 0, 'l' },
 
         /* Exclude devices, comma separated list */
-        {"exclude", required_argument, 0, 'e'},
+        { "exclude", required_argument, 0, 'e' },
 
         /* The Pseudo Random Number Generator. */
-        {"prng", required_argument, 0, 'p'},
+        { "prng", required_argument, 0, 'p' },
 
         /* The number of times to run the method. */
-        {"rounds", required_argument, 0, 'r'},
+        { "rounds", required_argument, 0, 'r' },
 
         /* Whether to blank the disk after wiping. */
-        {"noblank", no_argument, 0, 0},
+        { "noblank", no_argument, 0, 0 },
 
         /* Whether to ignore all USB devices. */
-        {"nousb", no_argument, 0, 0},
+        { "nousb", no_argument, 0, 0 },
 
         /* Whether to exit after wiping or wait for a keypress. */
-        {"nowait", no_argument, 0, 0},
+        { "nowait", no_argument, 0, 0 },
 
         /* Whether to allow signals to interrupt a wipe. */
-        {"nosignals", no_argument, 0, 0},
+        { "nosignals", no_argument, 0, 0 },
 
         /* Whether to exit after wiping or wait for a keypress. */
-        {"nogui", no_argument, 0, 0},
+        { "nogui", no_argument, 0, 0 },
 
         /* A flag to indicate whether the devices whould be opened in sync mode. */
-        {"sync", required_argument, 0, 0},
+        { "sync", required_argument, 0, 0 },
 
         /* Verify that wipe patterns are being written to the device. */
-        {"verify", required_argument, 0, 0},
+        { "verify", required_argument, 0, 0 },
 
         /* Display program version. */
-        {"verbose", no_argument, 0, 'v'},
+        { "verbose", no_argument, 0, 'v' },
 
         /* Display program version. */
-        {"version", no_argument, 0, 'V'},
+        { "version", no_argument, 0, 'V' },
 
         /* Requisite padding for getopt(). */
-        {0, 0, 0, 0}};
+        { 0, 0, 0, 0 } };
 
     /* Set default options. */
     nwipe_options.autonuke = 0;
@@ -399,6 +399,9 @@ int nwipe_options_parse( int argc, char** argv )
 
 void nwipe_options_log( void )
 {
+    extern nwipe_prng_t nwipe_twister;
+    extern nwipe_prng_t nwipe_isaac;
+
     /**
      *  Prints a manifest of options to the log.
      */
@@ -444,6 +447,23 @@ void nwipe_options_log( void )
     }
 
     nwipe_log( NWIPE_LOG_NOTICE, "  banner   = %s", banner );
+
+    if( nwipe_options.prng == &nwipe_twister )
+    {
+        nwipe_log( NWIPE_LOG_NOTICE, "  prng     = Mersenne Twister" );
+    }
+    else
+    {
+        if( nwipe_options.prng == &nwipe_isaac )
+        {
+            nwipe_log( NWIPE_LOG_NOTICE, "  prng     = Isaac" );
+        }
+        else
+        {
+            nwipe_log( NWIPE_LOG_NOTICE, "  prng     = Undefined" );
+        }
+    }
+
     nwipe_log( NWIPE_LOG_NOTICE, "  method   = %s", nwipe_method_label( nwipe_options.method ) );
     nwipe_log( NWIPE_LOG_NOTICE, "  rounds   = %i", nwipe_options.rounds );
     nwipe_log( NWIPE_LOG_NOTICE, "  sync     = %i", nwipe_options.sync );
@@ -489,13 +509,13 @@ void display_help()
     puts( "                          for one minute. During this one minute delay you can" );
     puts( "                          abort the shutdown by typing sudo shutdown -c\n" );
     printf( "      --sync=NUM          Will perform a sync after NUM writes (default: %d)\n", DEFAULT_SYNC_RATE );
-    puts( "                          0 - fdatasync after the disk is completely written" );
-    puts( "                              fdatasync errors not detected until completion." );
-    puts( "                              0 is not recommended as disk errors may cause nwipe" );
-    puts( "                              to appear to hang" );
-    puts( "                          1 - fdatasync after every write" );
-    puts( "                              Warning: Lower values will reduce wipe speeds." );
-    puts( "                          1000000 - fdatasync after 1000000 writes etc.)\n" );
+    puts( "                          0    - fdatasync after the disk is completely written" );
+    puts( "                                 fdatasync errors not detected until completion." );
+    puts( "                                 0 is not recommended as disk errors may cause" );
+    puts( "                                 nwipe to appear to hang" );
+    puts( "                          1    - fdatasync after every write" );
+    puts( "                                 Warning: Lower values will reduce wipe speeds." );
+    puts( "                          1000 - fdatasync after 1000 writes etc.\n" );
     puts( "      --verify=TYPE       Whether to perform verification of erasure" );
     puts( "                          (default: last)" );
     puts( "                          off   - Do not verify" );
@@ -514,16 +534,16 @@ void display_help()
     puts( "  -p, --prng=METHOD       PRNG option (mersenne|twister|isaac)\n" );
     puts( "  -r, --rounds=NUM        Number of times to wipe the device using the selected" );
     puts( "                          method (default: 1)\n" );
-    puts( "      --noblank           Do not blank disk after wipe" );
+    puts( "      --noblank           Do NOT blank disk after wipe" );
     puts( "                          (default is to complete a final blank pass)\n" );
-    puts( "      --nowait            Do not wait for a key before exiting" );
+    puts( "      --nowait            Do NOT wait for a key before exiting" );
     puts( "                          (default is to wait)\n" );
-    puts( "      --nosignals         Do not allow signals to interrupt a wipe" );
+    puts( "      --nosignals         Do NOT allow signals to interrupt a wipe" );
     puts( "                          (default is to allow)\n" );
-    puts( "      --nogui             Do not show the GUI interface. Automatically invokes" );
+    puts( "      --nogui             Do NOT show the GUI interface. Automatically invokes" );
     puts( "                          the nowait option. Must be used with the --autonuke" );
     puts( "                          option. Send SIGUSR1 to log current stats\n" );
-    puts( "      --nousb             Do show or wipe any USB devices whether in GUI" );
+    puts( "      --nousb             Do NOT show or wipe any USB devices whether in GUI" );
     puts( "                          mode, --nogui or --autonuke modes.\n" );
     puts( "  -e, --exclude=DEVICES   Up to ten comma separated devices to be excluded" );
     puts( "                          --exclude=/dev/sdc" );
